@@ -1,9 +1,10 @@
 package Catmandu::Exporter::MAB2;
 
 #ABSTRACT: Package that exports MAB2 data
-our $VERSION = '0.02'; #VERSION
+our $VERSION = '0.03'; #VERSION
 
 use Catmandu::Sane;
+use MAB2::Writer::Disk;
 use MAB2::Writer::RAW;
 use MAB2::Writer::XML;
 use Moo;
@@ -22,6 +23,9 @@ sub _build_writer {
     if ( $type eq 'raw' ) {
         MAB2::Writer::RAW->new( fh => $self->fh );
     }
+    elsif ( $type eq 'disk' ) {
+        MAB2::Writer::Disk->new( fh => $self->fh );
+    }
     elsif ( $type eq 'xml' ) {
         MAB2::Writer::XML->new(
             fh              => $self->fh,
@@ -30,7 +34,7 @@ sub _build_writer {
         );
     }
     else {
-        croak("unknown type: $type");
+        die "unknown type: $type";
     }
 }
 
@@ -69,7 +73,7 @@ Catmandu::Exporter::MAB2 - Package that exports MAB2 data
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
