@@ -1,7 +1,7 @@
 package MAB2::Parser::RAW;
 
 # ABSTRACT: MAB2 RAW format parser
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use strict;
 use warnings;
@@ -15,8 +15,6 @@ Readonly my $END_OF_FIELD       => qq{\N{INFORMATION SEPARATOR TWO}};
 Readonly my $END_OF_RECORD      => qq{\N{INFORMATION SEPARATOR THREE}};
 
 
-# ToDo: use Moo
-
 sub new {
     my $class = shift;
     my $file  = shift;
@@ -113,7 +111,7 @@ MAB2::Parser::RAW - MAB2 RAW format parser
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -122,8 +120,6 @@ L<MAB2::Parser::RAW> is a parser for raw MAB2 records.
 L<MAB2::Parser::RAW> expects UTF-8 encoded files as input. Otherwise provide a 
 filehande with a specified I/O layer.
 
-Catmandu...
-
     use MAB2::Parser::RAW;
 
     my $parser = MAB2::Parser::RAW->new( $filename );
