@@ -1,7 +1,7 @@
 package MAB2::Writer::RAW;
 
 #ABSTRACT: MAB2 RAW format serializer
-our $VERSION = '0.02'; #VERSION
+our $VERSION = '0.03'; #VERSION
 
 use strict;
 use Moo;
@@ -13,10 +13,12 @@ Readonly my $SUBFIELD_INDICATOR => qq{\N{INFORMATION SEPARATOR ONE}};
 Readonly my $END_OF_FIELD       => qq{\N{INFORMATION SEPARATOR TWO}};
 Readonly my $END_OF_RECORD      => qq{\N{INFORMATION SEPARATOR THREE}};
 
+
 sub BUILD {
     my ($self) = @_;
 }
 
+
 sub _write_record {
     my ( $self, $record ) = @_;
     my $fh = $self->fh;
@@ -60,7 +62,43 @@ MAB2::Writer::RAW - MAB2 RAW format serializer
 
 =head1 VERSION
 
-version 0.02
+version 0.03
+
+=head1 SYNOPSIS
+
+L<MAB2::Writer::RAW> is a MAB2 serializer.
+
+    use MAB2::Writer::RAW;
+
+    my @mab_records = (
+
+        [
+          ['001', ' ', '_', '2415107-5'],
+          ['331', ' ', '_', 'Code4Lib journal'],
+          ['655', 'e', 'u', 'http://journal.code4lib.org/', 'z', 'kostenfrei'],
+          ...
+        ],
+        {
+          record => [
+              ['001', ' ', '_', '2415107-5'],
+              ['331', ' ', '_', 'Code4Lib journal'],
+              ['655', 'e', 'u', 'http://journal.code4lib.org/', 'z', 'kostenfrei'],
+              ...
+          ]
+        }
+    );
+
+    $writer = MAB2::Writer::RAW->new( fh => $fh );
+
+    foreach my $record (@mab_records) {
+        $writer->write($record);
+    }
+
+=head1 SUBROUTINES/METHODS
+
+=head2 new()
+
+=head2 _write_record()
 
 =head1 AUTHOR
 
